@@ -15,7 +15,7 @@
 #' This function also returns a  dataframe  with the batting partnerships
 #'
 #' @usage
-#' teamBatsmenPartnershipAllOppnAllMatchesPlot(matches,theTeam,main,plot=TRUE)
+#' teamBatsmenPartnershipAllOppnAllMatchesPlot(matches,theTeam,main,plot=1)
 #'
 #' @param matches
 #' All the matches of the team against all oppositions
@@ -28,7 +28,7 @@
 
 #'
 #'@param plot
-#' Whether the partnerships have top be rendered as a plot. If plot=FALSE the data frame is returned
+#' Whether the partnerships have top be rendered as a plot. Plot=1 (static),plot=2(interactive),plot=3(table)
 #'
 #' @return None or partnerships
 #'
@@ -61,8 +61,9 @@
 #'
 #' @export
 #'
-teamBatsmenPartnershipAllOppnAllMatchesPlot <- function(matches,theTeam,main,plot=TRUE){
+teamBatsmenPartnershipAllOppnAllMatchesPlot <- function(matches,theTeam,main,plot=1){
     team=batsman=nonStriker=runs=partnershipRuns=totalRuns=NULL
+    ggplotly=NULL
     a <- NULL
     a <-filter(matches,team==theTeam)
 
@@ -76,7 +77,7 @@ teamBatsmenPartnershipAllOppnAllMatchesPlot <- function(matches,theTeam,main,plo
     df <- filter(df,runs!=0)
     df <- arrange(df,desc(runs))
 
-    if(plot==TRUE){
+    if(plot == 1){ #ggplot2
         if(theTeam==main){
              plot.title <- paste(theTeam," batting partnerships")
         }else if(theTeam != main){
@@ -88,6 +89,20 @@ teamBatsmenPartnershipAllOppnAllMatchesPlot <- function(matches,theTeam,main,plo
             ggtitle(bquote(atop(.(plot.title),
                                 atop(italic("Data source:http://cricsheet.org/"),"")))) +
             theme(axis.text.x = element_text(angle = 90, hjust = 1))
+    } else if(plot == 2){ #ggplotly
+
+        if(theTeam==main){
+            plot.title <- paste(theTeam," batting partnerships")
+        }else if(theTeam != main){
+            plot.title <- paste(theTeam," batting partnerships against ", main)
+        }
+        g <- ggplot(data=df,aes(x=batsman,y=runs,fill=nonStriker))+
+            geom_bar(data=df,stat="identity") +
+            xlab("Batsman") + ylab("Partnership runs") +
+            ggtitle(plot.title) +
+            theme(axis.text.x = element_text(angle = 90, hjust = 1))
+        ggplotly(g)
+
     } else{
         df
     }
